@@ -61,7 +61,7 @@ def parse(page, domain=''):
     if meta:
         result['meta'] = meta[0]['content']
     metakeywords = soup.findAll('meta', {"name": "keywords", "content": True})
-    if meta:
+    if metakeywords:
         result['metakeywords'] = metakeywords[0]['content']
 
     addresses = pyap.parse(vis, country='CA')
@@ -190,6 +190,6 @@ if __name__ == '__main__':
     # res = requests.get('http://keywebpmt.com', timeout=20, headers=headers)
     # result = parse(res.content)
     import kumihotools
-    result,_ = standardScrape('adopttechnologies.com', parkingterms=kumihotools.parkingterms)
+    result,_ = standardScrape('ixsystems.com', parkingterms=kumihotools.parkingterms)
     # result, content = standardScrape('http://keywebpmt.com')
     print(result)
\ No newline at end of file
